# Dumbdan's Adventure Game

## Description

#### Dumbdan's Adventure is a arcade game, made with python using the module pygame. This project was concerned because a project in the UFCG (Federal University of Campina Grande). Easy to play, and with a joyful story, Dumbdan can easly delight players of all ages.

## Synopsis

#### The adventure begins when a little village is attacked by irracionals numbers, and the daughter of the mayor is captured. Then, a little boy named Dumbdan offers his services to rescue her, and goes in a mission with the sord of knowledge: a book.

## Installation

#### To play Dumbdan's Adventure you just need to install through the pyPI, using:
```
pip install Dumbdans-Adventure
```
#### and to play, its just run in your terminal:
```
python -m Dumbdans-Adventure 

```

### Version News:

- 0.0.1 : Screen with a name that says "Dumbdan is Comming Soon...";
- 0.0.2 : Added the spreet of the character and the basics of movimentation. 
